# eslint-config-tuya

相关资料

- [ESLint](http://eslint.cn/docs/rules/)
- [Typescript ESLint](https://github.com/typescript-eslint/typescript-eslint)
- [Typescript ESLint 中与 TSlint 的关联](https://github.com/typescript-eslint/typescript-eslint/blob/master/packages/eslint-plugin/ROADMAP.md)

已经内置相关依赖

```json
{
  "@typescript-eslint/eslint-plugin": "^3.2.0",
  "@typescript-eslint/parser": "^3.2.0",
  "babel-eslint": "^10.1.0",
  "eslint": "^7.2.0",
  "eslint-config-prettier": "^6.15.0",
  "eslint-plugin-import": "^2.21.2",
  "eslint-plugin-jest": "^24.1.3",
  "eslint-plugin-jsx-a11y": "^6.4.1",
  "eslint-plugin-prettier": "^3.2.0",
  "eslint-plugin-react": "^7.20.0",
  "eslint-plugin-react-hooks": "^4.0.4",
  "eslint-plugin-security": "^1.4.0",
  "prettier": "^2.2.1",
  "stylelint": "^13.6.0",
  "stylelint-config-standard": "^20.0.0",
  "stylelint-scss": "^3.17.2",
  "typescript": "^4.1.2"
}
```

因此，项目中无需安装以上依赖，防止版本冲突

### 配置方式

#### ESlint 配置

安装依赖

```sh
$ yarn add -D eslint-config-tuya
```

根目录下新建 `.eslintrc` 文件

```json
{
  "extends": [
    "tuya/{配置文件}"
  ]
}
```

其中 `{配置文件}` 有 6 种，组合不同的文件满足不同的项目 (**注：ts相关的预设都要放到最后一条**)

- security - 用于打开 eslint-plugin-security 中被关闭的全部规则
- browser - 浏览器环境
- node - Nodejs 环境
- react - React 环境 (包括 browser 环境)
- ts - Typescript 环境
- tsReact - Typescript React 环境 (包括 browser 环境)
- next - Next.js 环境
- tsNext - Typescript + Next.js 环境
- tsNextRelax - 宽松版的 tsNext 规则，方便迁移
- react-native - react native 配置
  > 需要额外安装 `yarn add eslint-config-airbnb eslint-plugin-react-native eslint-import-resolver-react-native -D`

extends 数组里的预设会按顺序覆盖，每个预设都带了 parser 字段，所以要用 ts 的话，ts 的预设需要放在最后，覆盖掉前面的 parser

示例：需要 Typescript + React + Browser + Nodejs

```js
module.exports = {
  extends: [
    'tuya/node',
    'tuya/tsReact'
  ]
}
```

#### Stylelint 配置

根目录下新建 `.stylelintrc.js` 文件

```js
module.exports = {
  extends: [
    "eslint-config-tuya/style.js"
  ]
}
```
